@@ -5,8 +5,11 @@ from dataclasses import dataclass, field
 from enum import Enum
 from typing import Any, Dict, List, Optional, Set, Union
 
+from pydantic import ValidationError
+
 from .. import schema as oai
-from .errors import ParseError, PropertyError
+from .. import utils
+from .errors import GeneratorError, ParseError, PropertyError
 from .properties import EnumProperty, Property, property_from_data
 from .reference import Reference
 from .responses import ListRefResponse, RefResponse, Response, response_from_data
@@ -17,6 +20,7 @@ class ParameterLocation(str, Enum):
 
     QUERY = "query"
     PATH = "path"
+    HEADER = "header"
 
 
 def import_string_from_reference(reference: Reference, prefix: str = "") -> str:
@@ -76,6 +80,7 @@ class Endpoint:
     relative_imports: Set[str] = field(default_factory=set)
     query_parameters: List[Property] = field(default_factory=list)
     path_parameters: List[Property] = field(default_factory=list)
+    header_parameters: List[Property] = field(default_factory=list)
     responses: List[Response] = field(default_factory=list)
     form_body_reference: Optional[Reference] = None
     json_body: Optional[Property] = None
@@ -162,6 +167,8 @@ class Endpoint:
                 endpoint.query_parameters.append(prop)
             elif param.param_in == ParameterLocation.PATH:
                 endpoint.path_parameters.append(prop)
+            elif param.param_in == ParameterLocation.HEADER:
+                endpoint.header_parameters.append(prop)
             else:
                 return ParseError(data=param, detail="Parameter must be declared in path or query")
         return endpoint
@@ -176,7 +183,7 @@ class Endpoint:
         endpoint = Endpoint(
             path=path,
             method=method,
-            description=data.description,
+            description=utils.remove_string_escapes(data.description) if data.description else "",
             name=data.operationId,
             requires_security=bool(data.security),
             tag=tag,
@@ -288,9 +295,12 @@ class GeneratorData:
     enums: Dict[str, EnumProperty]
 
     @staticmethod
-    def from_dict(d: Dict[str, Dict[str, Any]]) -> GeneratorData:
+    def from_dict(d: Dict[str, Dict[str, Any]]) -> Union[GeneratorData, GeneratorError]:
         """ Create an OpenAPI from dict """
-        openapi = oai.OpenAPI.parse_obj(d)
+        try:
+            openapi = oai.OpenAPI.parse_obj(d)
+        except ValidationError as e:
+            return GeneratorError(header="Failed to parse OpenAPI document", detail=str(e))
         if openapi.components is None or openapi.components.schemas is None:
             schemas = Schemas()
         else:
